# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aigc_ext.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from mecord import common_ext_pb2 as common__ext__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x61igc_ext.proto\x12\x02pb\x1a\x10\x63ommon_ext.proto\"J\n\x08TaskItem\x12\x0e\n\x06taskId\x18\x01 \x01(\x03\x12\x10\n\x08taskUUID\x18\x02 \x01(\t\x12\x0e\n\x06\x63onfig\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\t\"o\n\nGetTaskReq\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x11\n\tDeviceKey\x18\x02 \x01(\t\x12\x0f\n\x07widgets\x18\x03 \x03(\t\x12\r\n\x05token\x18\x04 \x01(\t\x12\r\n\x05limit\x18\x05 \x01(\x05\x12\x0e\n\x06\x65xtend\x18\x06 \x01(\t\"F\n\nGetTaskRes\x12\x1a\n\x04list\x18\x01 \x03(\x0b\x32\x0c.pb.TaskItem\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\r\n\x05\x63ount\x18\x03 \x01(\x03\"x\n\rTaskNotifyReq\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x10\n\x08taskUUID\x18\x02 \x01(\t\x12\"\n\ntaskStatus\x18\x03 \x01(\x0e\x32\x0e.pb.TaskStatus\x12\x12\n\nfailReason\x18\x04 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\t\"\x0f\n\rTaskNotifyRes\"o\n\x11\x41igcDeviceBindReq\x12\x11\n\tdeviceKey\x18\x01 \x01(\t\x12\x11\n\tGroupUUID\x18\x02 \x01(\t\x12 \n\tLabelType\x18\x03 \x01(\x0e\x32\r.pb.LabelType\x12\x12\n\nlabelValue\x18\x04 \x01(\t\"\x13\n\x11\x41igcDeviceBindRes\":\n\x13\x41igcDeviceUnBindReq\x12\x10\n\x08\x64\x65viceId\x18\x01 \x01(\x03\x12\x11\n\tdeviceKey\x18\x02 \x01(\t\"\x15\n\x13\x41igcDeviceUnBindRes\"7\n\x11\x41igcDeviceInfoReq\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x11\n\tdeviceKey\x18\x02 \x01(\t\"`\n\x11\x41igcDeviceInfoRes\x12\x11\n\tdeviceKey\x18\x01 \x01(\t\x12\x11\n\tgroupUUID\x18\x02 \x01(\t\x12\x16\n\x0eisCreateWidget\x18\x03 \x01(\x08\x12\r\n\x05token\x18\x04 \x01(\t\"\x11\n\x0f\x43reateWidgetReq\"%\n\x0f\x43reateWidgetRes\x12\x12\n\nwidgetUUID\x18\x01 \x01(\t\"9\n\x12UploadWidgetUrlReq\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x12\n\nwidgetUUID\x18\x02 \x01(\t\"6\n\x12UploadWidgetUrlRes\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x13\n\x0b\x63ontentType\x18\x02 \x01(\t\"3\n\x0fUploadWidgetReq\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x0f\n\x07\x66ileUrl\x18\x02 \x01(\t\"\"\n\x0fUploadWidgetRes\x12\x0f\n\x07\x63heckId\x18\x01 \x01(\x03\"8\n\x14UploadWidgetCheckReq\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x0f\n\x07\x63heckId\x18\x02 \x01(\x03\"R\n\x14UploadWidgetCheckRes\x12&\n\x06status\x18\x01 \x01(\x0e\x32\x16.pb.UploadWidgetStatus\x12\x12\n\nfailReason\x18\x02 \x01(\t\"\x88\x01\n\x12\x41igcCreateGroupReq\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12 \n\tlabelType\x18\x05 \x01(\x0e\x32\r.pb.LabelType\x12\x0f\n\x07labelId\x18\x06 \x01(\x03\x12\x0e\n\x06status\x18\x07 \x01(\x05\".\n\x12\x41igcCreateGroupRes\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04uuid\x18\x02 \x01(\t\"V\n\x12\x41igcRemoveGroupReq\x12\n\n\x02id\x18\x01 \x01(\x03\x12 \n\tlabelType\x18\x02 \x01(\x0e\x32\r.pb.LabelType\x12\x12\n\nlabelValue\x18\x03 \x01(\t\"\x14\n\x12\x41igcRemoveGroupRes\",\n\x0e\x41igcTaskResult\x12\x1a\n\x04list\x18\x01 \x03(\x0b\x32\x0c.pb.AigcData\"S\n\x08\x41igcData\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x03(\t\x12(\n\textension\x18\x03 \x01(\x0b\x32\x15.pb.AigcDataExtension\"S\n\x11\x41igcDataExtension\x12\x0c\n\x04info\x18\x01 \x01(\t\x12\x11\n\tcover_url\x18\x02 \x01(\t\x12\x0e\n\x06height\x18\x03 \x01(\t\x12\r\n\x05width\x18\x04 \x01(\t\"C\n\x10UploadFileUrlReq\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\x12\x0f\n\x07\x66ileExt\x18\x03 \x01(\t\"4\n\x10UploadFileUrlRes\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x13\n\x0b\x63ontentType\x18\x02 \x01(\t*X\n\x12UploadWidgetStatus\x12\x0c\n\x08UWS_NONE\x10\x00\x12\x12\n\x0eUWS_PROCESSING\x10\x01\x12\x0f\n\x0bUWS_SUCCESS\x10\x02\x12\x0f\n\x0bUWS_FAILURE\x10\x03\x32\xdf\x04\n\nAigcExtObj\x12)\n\x07GetTask\x12\x0e.pb.GetTaskReq\x1a\x0e.pb.GetTaskRes\x12\x32\n\nTaskNotify\x12\x11.pb.TaskNotifyReq\x1a\x11.pb.TaskNotifyRes\x12:\n\nDeviceBind\x12\x15.pb.AigcDeviceBindReq\x1a\x15.pb.AigcDeviceBindRes\x12:\n\nDeviceInfo\x12\x15.pb.AigcDeviceInfoReq\x1a\x15.pb.AigcDeviceInfoRes\x12\x38\n\x0c\x43reateWidget\x12\x13.pb.CreateWidgetReq\x1a\x13.pb.CreateWidgetRes\x12\x38\n\x0cUploadWidget\x12\x13.pb.UploadWidgetReq\x1a\x13.pb.UploadWidgetRes\x12\x41\n\x0fUploadWidgetUrl\x12\x16.pb.UploadWidgetUrlReq\x1a\x16.pb.UploadWidgetUrlRes\x12;\n\rUploadFileUrl\x12\x14.pb.UploadFileUrlReq\x1a\x14.pb.UploadFileUrlRes\x12G\n\x11UploadWidgetCheck\x12\x18.pb.UploadWidgetCheckReq\x1a\x18.pb.UploadWidgetCheckRes\x12=\n\x0bRemoveGroup\x12\x16.pb.AigcRemoveGroupReq\x1a\x16.pb.AigcRemoveGroupResB\x06\xa2\x02\x03PB3b\x06proto3')

_UPLOADWIDGETSTATUS = DESCRIPTOR.enum_types_by_name['UploadWidgetStatus']
UploadWidgetStatus = enum_type_wrapper.EnumTypeWrapper(_UPLOADWIDGETSTATUS)
UWS_NONE = 0
UWS_PROCESSING = 1
UWS_SUCCESS = 2
UWS_FAILURE = 3


_TASKITEM = DESCRIPTOR.message_types_by_name['TaskItem']
_GETTASKREQ = DESCRIPTOR.message_types_by_name['GetTaskReq']
_GETTASKRES = DESCRIPTOR.message_types_by_name['GetTaskRes']
_TASKNOTIFYREQ = DESCRIPTOR.message_types_by_name['TaskNotifyReq']
_TASKNOTIFYRES = DESCRIPTOR.message_types_by_name['TaskNotifyRes']
_AIGCDEVICEBINDREQ = DESCRIPTOR.message_types_by_name['AigcDeviceBindReq']
_AIGCDEVICEBINDRES = DESCRIPTOR.message_types_by_name['AigcDeviceBindRes']
_AIGCDEVICEUNBINDREQ = DESCRIPTOR.message_types_by_name['AigcDeviceUnBindReq']
_AIGCDEVICEUNBINDRES = DESCRIPTOR.message_types_by_name['AigcDeviceUnBindRes']
_AIGCDEVICEINFOREQ = DESCRIPTOR.message_types_by_name['AigcDeviceInfoReq']
_AIGCDEVICEINFORES = DESCRIPTOR.message_types_by_name['AigcDeviceInfoRes']
_CREATEWIDGETREQ = DESCRIPTOR.message_types_by_name['CreateWidgetReq']
_CREATEWIDGETRES = DESCRIPTOR.message_types_by_name['CreateWidgetRes']
_UPLOADWIDGETURLREQ = DESCRIPTOR.message_types_by_name['UploadWidgetUrlReq']
_UPLOADWIDGETURLRES = DESCRIPTOR.message_types_by_name['UploadWidgetUrlRes']
_UPLOADWIDGETREQ = DESCRIPTOR.message_types_by_name['UploadWidgetReq']
_UPLOADWIDGETRES = DESCRIPTOR.message_types_by_name['UploadWidgetRes']
_UPLOADWIDGETCHECKREQ = DESCRIPTOR.message_types_by_name['UploadWidgetCheckReq']
_UPLOADWIDGETCHECKRES = DESCRIPTOR.message_types_by_name['UploadWidgetCheckRes']
_AIGCCREATEGROUPREQ = DESCRIPTOR.message_types_by_name['AigcCreateGroupReq']
_AIGCCREATEGROUPRES = DESCRIPTOR.message_types_by_name['AigcCreateGroupRes']
_AIGCREMOVEGROUPREQ = DESCRIPTOR.message_types_by_name['AigcRemoveGroupReq']
_AIGCREMOVEGROUPRES = DESCRIPTOR.message_types_by_name['AigcRemoveGroupRes']
_AIGCTASKRESULT = DESCRIPTOR.message_types_by_name['AigcTaskResult']
_AIGCDATA = DESCRIPTOR.message_types_by_name['AigcData']
_AIGCDATAEXTENSION = DESCRIPTOR.message_types_by_name['AigcDataExtension']
_UPLOADFILEURLREQ = DESCRIPTOR.message_types_by_name['UploadFileUrlReq']
_UPLOADFILEURLRES = DESCRIPTOR.message_types_by_name['UploadFileUrlRes']
TaskItem = _reflection.GeneratedProtocolMessageType('TaskItem', (_message.Message,), {
  'DESCRIPTOR' : _TASKITEM,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.TaskItem)
  })
_sym_db.RegisterMessage(TaskItem)

GetTaskReq = _reflection.GeneratedProtocolMessageType('GetTaskReq', (_message.Message,), {
  'DESCRIPTOR' : _GETTASKREQ,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.GetTaskReq)
  })
_sym_db.RegisterMessage(GetTaskReq)

GetTaskRes = _reflection.GeneratedProtocolMessageType('GetTaskRes', (_message.Message,), {
  'DESCRIPTOR' : _GETTASKRES,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.GetTaskRes)
  })
_sym_db.RegisterMessage(GetTaskRes)

TaskNotifyReq = _reflection.GeneratedProtocolMessageType('TaskNotifyReq', (_message.Message,), {
  'DESCRIPTOR' : _TASKNOTIFYREQ,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.TaskNotifyReq)
  })
_sym_db.RegisterMessage(TaskNotifyReq)

TaskNotifyRes = _reflection.GeneratedProtocolMessageType('TaskNotifyRes', (_message.Message,), {
  'DESCRIPTOR' : _TASKNOTIFYRES,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.TaskNotifyRes)
  })
_sym_db.RegisterMessage(TaskNotifyRes)

AigcDeviceBindReq = _reflection.GeneratedProtocolMessageType('AigcDeviceBindReq', (_message.Message,), {
  'DESCRIPTOR' : _AIGCDEVICEBINDREQ,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AigcDeviceBindReq)
  })
_sym_db.RegisterMessage(AigcDeviceBindReq)

AigcDeviceBindRes = _reflection.GeneratedProtocolMessageType('AigcDeviceBindRes', (_message.Message,), {
  'DESCRIPTOR' : _AIGCDEVICEBINDRES,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AigcDeviceBindRes)
  })
_sym_db.RegisterMessage(AigcDeviceBindRes)

AigcDeviceUnBindReq = _reflection.GeneratedProtocolMessageType('AigcDeviceUnBindReq', (_message.Message,), {
  'DESCRIPTOR' : _AIGCDEVICEUNBINDREQ,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AigcDeviceUnBindReq)
  })
_sym_db.RegisterMessage(AigcDeviceUnBindReq)

AigcDeviceUnBindRes = _reflection.GeneratedProtocolMessageType('AigcDeviceUnBindRes', (_message.Message,), {
  'DESCRIPTOR' : _AIGCDEVICEUNBINDRES,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AigcDeviceUnBindRes)
  })
_sym_db.RegisterMessage(AigcDeviceUnBindRes)

AigcDeviceInfoReq = _reflection.GeneratedProtocolMessageType('AigcDeviceInfoReq', (_message.Message,), {
  'DESCRIPTOR' : _AIGCDEVICEINFOREQ,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AigcDeviceInfoReq)
  })
_sym_db.RegisterMessage(AigcDeviceInfoReq)

AigcDeviceInfoRes = _reflection.GeneratedProtocolMessageType('AigcDeviceInfoRes', (_message.Message,), {
  'DESCRIPTOR' : _AIGCDEVICEINFORES,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AigcDeviceInfoRes)
  })
_sym_db.RegisterMessage(AigcDeviceInfoRes)

CreateWidgetReq = _reflection.GeneratedProtocolMessageType('CreateWidgetReq', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWIDGETREQ,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.CreateWidgetReq)
  })
_sym_db.RegisterMessage(CreateWidgetReq)

CreateWidgetRes = _reflection.GeneratedProtocolMessageType('CreateWidgetRes', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWIDGETRES,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.CreateWidgetRes)
  })
_sym_db.RegisterMessage(CreateWidgetRes)

UploadWidgetUrlReq = _reflection.GeneratedProtocolMessageType('UploadWidgetUrlReq', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADWIDGETURLREQ,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.UploadWidgetUrlReq)
  })
_sym_db.RegisterMessage(UploadWidgetUrlReq)

UploadWidgetUrlRes = _reflection.GeneratedProtocolMessageType('UploadWidgetUrlRes', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADWIDGETURLRES,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.UploadWidgetUrlRes)
  })
_sym_db.RegisterMessage(UploadWidgetUrlRes)

UploadWidgetReq = _reflection.GeneratedProtocolMessageType('UploadWidgetReq', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADWIDGETREQ,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.UploadWidgetReq)
  })
_sym_db.RegisterMessage(UploadWidgetReq)

UploadWidgetRes = _reflection.GeneratedProtocolMessageType('UploadWidgetRes', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADWIDGETRES,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.UploadWidgetRes)
  })
_sym_db.RegisterMessage(UploadWidgetRes)

UploadWidgetCheckReq = _reflection.GeneratedProtocolMessageType('UploadWidgetCheckReq', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADWIDGETCHECKREQ,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.UploadWidgetCheckReq)
  })
_sym_db.RegisterMessage(UploadWidgetCheckReq)

UploadWidgetCheckRes = _reflection.GeneratedProtocolMessageType('UploadWidgetCheckRes', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADWIDGETCHECKRES,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.UploadWidgetCheckRes)
  })
_sym_db.RegisterMessage(UploadWidgetCheckRes)

AigcCreateGroupReq = _reflection.GeneratedProtocolMessageType('AigcCreateGroupReq', (_message.Message,), {
  'DESCRIPTOR' : _AIGCCREATEGROUPREQ,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AigcCreateGroupReq)
  })
_sym_db.RegisterMessage(AigcCreateGroupReq)

AigcCreateGroupRes = _reflection.GeneratedProtocolMessageType('AigcCreateGroupRes', (_message.Message,), {
  'DESCRIPTOR' : _AIGCCREATEGROUPRES,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AigcCreateGroupRes)
  })
_sym_db.RegisterMessage(AigcCreateGroupRes)

AigcRemoveGroupReq = _reflection.GeneratedProtocolMessageType('AigcRemoveGroupReq', (_message.Message,), {
  'DESCRIPTOR' : _AIGCREMOVEGROUPREQ,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AigcRemoveGroupReq)
  })
_sym_db.RegisterMessage(AigcRemoveGroupReq)

AigcRemoveGroupRes = _reflection.GeneratedProtocolMessageType('AigcRemoveGroupRes', (_message.Message,), {
  'DESCRIPTOR' : _AIGCREMOVEGROUPRES,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AigcRemoveGroupRes)
  })
_sym_db.RegisterMessage(AigcRemoveGroupRes)

AigcTaskResult = _reflection.GeneratedProtocolMessageType('AigcTaskResult', (_message.Message,), {
  'DESCRIPTOR' : _AIGCTASKRESULT,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AigcTaskResult)
  })
_sym_db.RegisterMessage(AigcTaskResult)

AigcData = _reflection.GeneratedProtocolMessageType('AigcData', (_message.Message,), {
  'DESCRIPTOR' : _AIGCDATA,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AigcData)
  })
_sym_db.RegisterMessage(AigcData)

AigcDataExtension = _reflection.GeneratedProtocolMessageType('AigcDataExtension', (_message.Message,), {
  'DESCRIPTOR' : _AIGCDATAEXTENSION,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AigcDataExtension)
  })
_sym_db.RegisterMessage(AigcDataExtension)

UploadFileUrlReq = _reflection.GeneratedProtocolMessageType('UploadFileUrlReq', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADFILEURLREQ,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.UploadFileUrlReq)
  })
_sym_db.RegisterMessage(UploadFileUrlReq)

UploadFileUrlRes = _reflection.GeneratedProtocolMessageType('UploadFileUrlRes', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADFILEURLRES,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.UploadFileUrlRes)
  })
_sym_db.RegisterMessage(UploadFileUrlRes)

_AIGCEXTOBJ = DESCRIPTOR.services_by_name['AigcExtObj']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\242\002\003PB3'
  _UPLOADWIDGETSTATUS._serialized_start=1852
  _UPLOADWIDGETSTATUS._serialized_end=1940
  _TASKITEM._serialized_start=40
  _TASKITEM._serialized_end=114
  _GETTASKREQ._serialized_start=116
  _GETTASKREQ._serialized_end=227
  _GETTASKRES._serialized_start=229
  _GETTASKRES._serialized_end=299
  _TASKNOTIFYREQ._serialized_start=301
  _TASKNOTIFYREQ._serialized_end=421
  _TASKNOTIFYRES._serialized_start=423
  _TASKNOTIFYRES._serialized_end=438
  _AIGCDEVICEBINDREQ._serialized_start=440
  _AIGCDEVICEBINDREQ._serialized_end=551
  _AIGCDEVICEBINDRES._serialized_start=553
  _AIGCDEVICEBINDRES._serialized_end=572
  _AIGCDEVICEUNBINDREQ._serialized_start=574
  _AIGCDEVICEUNBINDREQ._serialized_end=632
  _AIGCDEVICEUNBINDRES._serialized_start=634
  _AIGCDEVICEUNBINDRES._serialized_end=655
  _AIGCDEVICEINFOREQ._serialized_start=657
  _AIGCDEVICEINFOREQ._serialized_end=712
  _AIGCDEVICEINFORES._serialized_start=714
  _AIGCDEVICEINFORES._serialized_end=810
  _CREATEWIDGETREQ._serialized_start=812
  _CREATEWIDGETREQ._serialized_end=829
  _CREATEWIDGETRES._serialized_start=831
  _CREATEWIDGETRES._serialized_end=868
  _UPLOADWIDGETURLREQ._serialized_start=870
  _UPLOADWIDGETURLREQ._serialized_end=927
  _UPLOADWIDGETURLRES._serialized_start=929
  _UPLOADWIDGETURLRES._serialized_end=983
  _UPLOADWIDGETREQ._serialized_start=985
  _UPLOADWIDGETREQ._serialized_end=1036
  _UPLOADWIDGETRES._serialized_start=1038
  _UPLOADWIDGETRES._serialized_end=1072
  _UPLOADWIDGETCHECKREQ._serialized_start=1074
  _UPLOADWIDGETCHECKREQ._serialized_end=1130
  _UPLOADWIDGETCHECKRES._serialized_start=1132
  _UPLOADWIDGETCHECKRES._serialized_end=1214
  _AIGCCREATEGROUPREQ._serialized_start=1217
  _AIGCCREATEGROUPREQ._serialized_end=1353
  _AIGCCREATEGROUPRES._serialized_start=1355
  _AIGCCREATEGROUPRES._serialized_end=1401
  _AIGCREMOVEGROUPREQ._serialized_start=1403
  _AIGCREMOVEGROUPREQ._serialized_end=1489
  _AIGCREMOVEGROUPRES._serialized_start=1491
  _AIGCREMOVEGROUPRES._serialized_end=1511
  _AIGCTASKRESULT._serialized_start=1513
  _AIGCTASKRESULT._serialized_end=1557
  _AIGCDATA._serialized_start=1559
  _AIGCDATA._serialized_end=1642
  _AIGCDATAEXTENSION._serialized_start=1644
  _AIGCDATAEXTENSION._serialized_end=1727
  _UPLOADFILEURLREQ._serialized_start=1729
  _UPLOADFILEURLREQ._serialized_end=1796
  _UPLOADFILEURLRES._serialized_start=1798
  _UPLOADFILEURLRES._serialized_end=1850
  _AIGCEXTOBJ._serialized_start=1943
  _AIGCEXTOBJ._serialized_end=2550
# @@protoc_insertion_point(module_scope)
