# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common_ext.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x63ommon_ext.proto\x12\x02pb\"\xf7\x02\n\x06Player\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x10\n\x08nickname\x18\x02 \x01(\t\x12\x18\n\x03sex\x18\x03 \x01(\x0e\x32\x0b.pb.SexType\x12\x0b\n\x03id2\x18\x04 \x01(\x03\x12\x0c\n\x04icon\x18\x05 \x01(\t\x12\r\n\x05\x66lags\x18\x06 \x01(\x03\x12\r\n\x05\x63harm\x18\x08 \x01(\x03\x12\x13\n\x0b\x63harm_level\x18\t \x01(\x05\x12\x14\n\x0cwealth_level\x18\n \x01(\x05\x12\x0e\n\x06wealth\x18\x0b \x01(\x03\x12\x12\n\nonline_exp\x18\x0c \x01(\r\x12\x11\n\tcreate_at\x18\r \x01(\r\x12\x11\n\tis_delete\x18\x0e \x01(\x08\x12\r\n\x05point\x18\x0f \x01(\x03\x12\x13\n\x0bpoint_level\x18\x10 \x01(\x05\x12\x11\n\tsignature\x18\x11 \x01(\t\x12\x0c\n\x04\x63ity\x18\x12 \x01(\t\x12\x10\n\x08\x62irthday\x18\x13 \x01(\t\x12\x14\n\x0conline_state\x18\x14 \x01(\x05\x12\x1a\n\x12NicknameUpdateTime\x18\x15 \x01(\r\"\x81\x01\n\x08UserInfo\x12\n\n\x02id\x18\x01 \x01(\x12\x12\x0c\n\x04\x63ity\x18\x02 \x01(\t\x12\x11\n\tsignature\x18\x03 \x01(\t\x12\x0c\n\x04mind\x18\x04 \x01(\t\x12\x10\n\x08\x62irthday\x18\x05 \x01(\t\x12\x15\n\rintimate_slot\x18\x06 \x01(\x11\x12\x11\n\tnameplate\x18\x07 \x01(\t\"\xd7\x02\n\nPlayerInfo\x12\x1a\n\x06player\x18\x01 \x01(\x0b\x32\n.pb.Player\x12\x1a\n\x06\x65\x66\x66\x65\x63t\x18\x02 \x03(\x0b\x32\n.pb.Effect\x12\x1a\n\x04\x63lan\x18\x03 \x01(\x0b\x32\x0c.pb.ClanInfo\x12\x10\n\x08\x66\x61ns_num\x18\x04 \x01(\x05\x12\x15\n\rfollowing_num\x18\x05 \x01(\x05\x12\x14\n\x0c\x66riend_alias\x18\x06 \x01(\t\x12\x1f\n\x07\x65\x66\x66\x65\x63ts\x18\x07 \x03(\x0b\x32\x0e.pb.EffectInfo\x12\x18\n\x10\x61ttitude_yes_num\x18\x08 \x01(\x03\x12\x17\n\x0ftotal_visit_num\x18\t \x01(\x03\x12\x15\n\radd_visit_num\x18\n \x01(\x03\x12\x1c\n\x05label\x18\x0b \x03(\x0b\x32\r.pb.LabelInfo\x12-\n\x0c\x64\x65grees_info\x18\x0c \x01(\x0b\x32\x17.pb.AttitudeDegreesInfo\"=\n\x07\x42\x61gItem\x12\x0f\n\x07gift_id\x18\x01 \x01(\r\x12\x0e\n\x06\x61mount\x18\x02 \x01(\r\x12\x11\n\tcteate_at\x18\x03 \x01(\t\"\"\n\x08\x41godaKey\x12\x16\n\x0epermission_key\x18\x01 \x01(\t\":\n\x0bOnOffStatus\x12\x0e\n\x06status\x18\x01 \x01(\x11\x12\x1b\n\x04type\x18\x02 \x01(\x0e\x32\r.pb.OnOffType\"\xf8\x01\n\x11SearchPlayerEntry\x12\n\n\x02id\x18\x01 \x01(\x12\x12\x0b\n\x03id2\x18\x02 \x01(\x12\x12\x10\n\x08nickname\x18\x03 \x01(\t\x12\x18\n\x03sex\x18\x04 \x01(\x0e\x32\x0b.pb.SexType\x12\x0c\n\x04icon\x18\x05 \x01(\t\x12\r\n\x05\x63harm\x18\x06 \x01(\x12\x12\x13\n\x0b\x63harm_level\x18\x07 \x01(\x11\x12\x0e\n\x06wealth\x18\x08 \x01(\x12\x12\x14\n\x0cwealth_level\x18\t \x01(\x11\x12\x0e\n\x06online\x18\n \x01(\x08\x12\x0f\n\x07room_id\x18\x0b \x01(\x12\x12\x12\n\nhas_passwd\x18\r \x01(\x08\x12\x11\n\tsignature\x18\x0e \x01(\t\"\x9f\x01\n\nEffectInfo\x12\n\n\x02id\x18\x01 \x01(\x03\x12%\n\ttime_type\x18\x02 \x01(\x0e\x32\x12.pb.EffectTimeType\x12\x10\n\x08\x65nd_time\x18\x03 \x01(\x03\x12\'\n\nuse_status\x18\x04 \x01(\x0e\x32\x13.pb.EffectUseStatus\x12#\n\x0b\x65\x66\x66\x65\x63t_type\x18\x05 \x01(\x0e\x32\x0e.pb.EffectType\"\xaf\x01\n\x06\x45\x66\x66\x65\x63t\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04\x66lag\x18\x02 \x01(\x05\x12\x0b\n\x03str\x18\x03 \x01(\t\x12%\n\ttime_type\x18\x04 \x01(\x0e\x32\x12.pb.EffectTimeType\x12\x10\n\x08\x65nd_time\x18\x05 \x01(\x05\x12\'\n\nuse_status\x18\x06 \x01(\x0e\x32\x13.pb.EffectUseStatus\x12\x1c\n\x04type\x18\x07 \x01(\x0e\x32\x0e.pb.EffectType\"T\n\x0c\x45\x66\x66\x65\x63tConfig\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x1c\n\x04type\x18\x02 \x01(\x0e\x32\x0e.pb.EffectType\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\"6\n\x15\x45\x66\x66\x65\x63tNicknamePendant\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x10\n\x08show_url\x18\x02 \x01(\t\"G\n\rEffectSerConf\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x1c\n\x04type\x18\x02 \x01(\x0e\x32\x0e.pb.EffectType\x12\x0c\n\x04name\x18\x03 \x01(\t\"0\n\rIndexTipRooms\x12\x0f\n\x07room_id\x18\x01 \x01(\x03\x12\x0e\n\x06tip_id\x18\x02 \x01(\x05\"=\n\x07RegisId\x12\x0b\n\x03ios\x18\x01 \x01(\t\x12\x0f\n\x07\x61ndroid\x18\x02 \x01(\t\x12\x14\n\x0cmanufacturer\x18\x03 \x01(\t\"P\n\nModelOnOff\x12\x1c\n\x05onOff\x18\x01 \x01(\x0e\x32\r.pb.OnOffType\x12$\n\x06status\x18\x02 \x01(\x0e\x32\x14.pb.ModelOnOffStatus\"\xd0\x01\n\x04Rank\x12\n\n\x02id\x18\x01 \x01(\x12\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x18\n\x03sex\x18\x03 \x01(\x0e\x32\x0b.pb.SexType\x12\r\n\x05level\x18\x04 \x01(\r\x12\r\n\x05value\x18\x05 \x01(\x04\x12\x10\n\x08res_time\x18\x06 \x01(\r\x12\x0f\n\x07gap_val\x18\x07 \x01(\r\x12\x0c\n\x04icon\x18\x08 \x01(\t\x12\x0f\n\x07gift_id\x18\t \x01(\x04\x12\x10\n\x08gift_num\x18\n \x01(\r\x12\x0f\n\x07ranking\x18\x0b \x01(\r\x12\x11\n\tgift_name\x18\x0c \x01(\t\"5\n\x0fPlayerChairRoom\x12\x11\n\tplayer_id\x18\x01 \x01(\x03\x12\x0f\n\x07room_id\x18\x02 \x01(\x03\"l\n\x08\x43lanInfo\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x11\n\ticon_word\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05level\x18\x04 \x01(\x03\x12\x12\n\nlevel_name\x18\x05 \x01(\t\x12\x10\n\x08is_admin\x18\x06 \x01(\x08\"*\n\x06Period\x12\x10\n\x08\x62\x65gin_at\x18\x01 \x01(\x03\x12\x0e\n\x06\x65nd_at\x18\x02 \x01(\x03\",\n\tLabelInfo\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x13\n\x0b\x63lassify_id\x18\x02 \x01(\x05\"Y\n\x13PlayerResourceShort\x12-\n\rresource_type\x18\x01 \x01(\x0e\x32\x16.pb.PlayerResourceType\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\"\x96\x01\n\x0ePlayerResource\x12-\n\rresource_type\x18\x01 \x01(\x0e\x32\x16.pb.PlayerResourceType\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\x12\x10\n\x08nickname\x18\x03 \x01(\t\x12\x14\n\x0chead_img_url\x18\x04 \x01(\t\x12\x18\n\x03sex\x18\x05 \x01(\x0e\x32\x0b.pb.SexType\"c\n\x17PlayerResourceWithScore\x12+\n\x0fplayer_resource\x18\x01 \x01(\x0b\x32\x12.pb.PlayerResource\x12\r\n\x05score\x18\x02 \x01(\x03\x12\x0c\n\x04rank\x18\x03 \x01(\x05\"\xb4\x01\n\x13\x41ttitudeDegreesInfo\x12\x35\n\x0e\x64\x65grees_status\x18\x01 \x01(\x0e\x32\x1d.pb.AttitudeDegreesStatusType\x12\x36\n\rcategory_info\x18\x02 \x03(\x0b\x32\x1f.pb.AttitudeCategoryDegreesInfo\x12\x14\n\x0ctotal_degree\x18\x03 \x01(\x05\x12\x18\n\x10\x61nalysis_content\x18\x04 \x01(\t\"g\n\x1b\x41ttitudeCategoryDegreesInfo\x12\x13\n\x0b\x63\x61tegory_id\x18\x01 \x01(\x05\x12\x15\n\rcategory_name\x18\x02 \x01(\t\x12\x0e\n\x06\x64\x65gree\x18\x03 \x01(\x05\x12\x0c\n\x04icon\x18\x04 \x01(\t\"\x85\x01\n\x0e\x43MediaResource\x12\"\n\nmedia_type\x18\x01 \x01(\x0e\x32\x0e.pb.CMediaType\x12\x11\n\tmedia_url\x18\x02 \x01(\t\x12\x11\n\tcover_url\x18\x03 \x01(\t\x12\x13\n\x0bmedia_width\x18\x04 \x01(\x05\x12\x14\n\x0cmedia_height\x18\x05 \x01(\x05\"\x1b\n\x0bSayHelloReq\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x1c\n\x0bSayHelloRes\x12\r\n\x05reply\x18\x01 \x01(\t\"b\n\x0cHeartbeatReq\x12\x0f\n\x07goim_id\x18\x01 \x01(\x03\x12\x11\n\tplayer_id\x18\x02 \x01(\x03\x12\n\n\x02ip\x18\x03 \x01(\t\x12\"\n\ndeviceType\x18\x04 \x01(\x0e\x32\x0e.pb.DeviceType\"!\n\x0cHeartbeatRes\x12\x11\n\ttimestamp\x18\x02 \x01(\x03*\xad\x01\n\tCommonErr\x12\x0f\n\x0b\x45rrCodeNone\x10\x00\x12\x11\n\x0c\x45rrCodeRedis\x10\x91N\x12\x11\n\x0c\x45rrCodeMysql\x10\x92N\x12\x15\n\x10\x45rrCodeFrequency\x10\x93N\x12\x11\n\x0c\x45rrCodeParam\x10\x94N\x12\x16\n\x11\x45rrCodeNoMatchObj\x10\x95N\x12\x10\n\x0b\x45rrCodeBusy\x10\x96N\x12\x15\n\x0f\x45rrCodeMaintain\x10\x9a\x82\x01*,\n\x07SexType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04MALE\x10\x01\x12\n\n\x06\x46\x45MALE\x10\x02*0\n\x0bOwnerInRoom\x12\x11\n\rNotInSelfRoom\x10\x00\x12\x0e\n\nInSelfRoom\x10\x01*%\n\tSceneType\x12\x0b\n\x07ST_ZERO\x10\x00\x12\x0b\n\x07ST_HOME\x10\x01*y\n\rRoomAdminType\x12\r\n\tRAT_GUEST\x10\x00\x12\x0e\n\nRAT_NORMAL\x10\n\x12\r\n\tRAT_ADMIN\x10\x14\x12\r\n\tRAT_OWNER\x10\x1e\x12\x13\n\x0fRAT_SUPER_ADMIN\x10(\x12\x16\n\tRAT_BLACK\x10\xfb\xff\xff\xff\xff\xff\xff\xff\xff\x01*\xfb\x01\n\nDeviceType\x12\x0e\n\nDT_UNKNOWN\x10\x00\x12\x12\n\x0e\x44T_FLASHPLAYER\x10\x01\x12\x14\n\x10\x44T_ANDROID_PHONE\x10\x14\x12\x10\n\x0c\x44T_IOS_PHONE\x10(\x12\x18\n\x14\x44T_WINDOWS_ASSISTANT\x10P\x12\x11\n\rDT_WINDOWS_PC\x10Z\x12\x0c\n\x08\x44T_ROBOT\x10\x64\x12\x1a\n\x16\x44T_WECHAT_SUBSCRIPTION\x10n\x12\x17\n\x13\x44T_QQ_SMALL_PROGRAM\x10x\x12\x17\n\x12\x44T_WX_MINI_PROGRAM\x10\x82\x01\x12\x0b\n\x06\x44T_WEB\x10\x8c\x01\x12\x0b\n\x06\x44T_MAC\x10\x96\x01*\x99\x01\n\x0bPlayerFlags\x12\x0b\n\x07PF_ZERO\x10\x00\x12\x14\n\x10PF_CERTIFICATION\x10\x01\x12\x10\n\x0cPF_BIND_BANK\x10\x04\x12\r\n\tPF_INVITE\x10\x05\x12\x13\n\x0fPF_CHARGE_FIRST\x10\x0c\x12\x18\n\x14PF_ATTITUDE_QUESTION\x10\r\x12\x17\n\x13PF_END_REGISTRATION\x10\x0e*2\n\x0c\x41\x63\x63ountFlags\x12\x0b\n\x07\x41\x46_ZERO\x10\x00\x12\x15\n\x11\x41\x46_PHONE_VERIFIED\x10\x01*\xfc\r\n\tOnOffType\x12\x0c\n\x08YEAR_BAG\x10\x00\x12\r\n\tCRACK_EGG\x10\x01\x12\x0e\n\nGOOGLE_PAY\x10\x05\x12\x0b\n\x07IAP_PAY\x10\x06\x12\n\n\x06INVITE\x10\x07\x12\x12\n\x0eINDEX_CATEGORY\x10\x08\x12\n\n\x06\x43\x45RTIF\x10\t\x12\t\n\x05GUARD\x10\n\x12\x10\n\x0cLOTTERY_DRAW\x10\x0c\x12\x0f\n\x0bMENTOR_SHIP\x10\r\x12\x0e\n\nCERTIF_IOS\x10\x0e\x12\x11\n\rREAL_IDENTITY\x10\x0f\x12\x0f\n\x0bNOVICE_GIFT\x10\x10\x12\x12\n\x0eROOM_SET_MODEL\x10\x12\x12\x11\n\rACTIVITY_TYPE\x10\x14\x12\x0c\n\x08\x41\x43TIVITY\x10\x15\x12\x0c\n\x08HOT_SONG\x10\x17\x12\x0e\n\nROOM_ENTER\x10\"\x12\x1d\n\x19ROOM_PATTERN_HIGH_QUALITY\x10#\x12\x11\n\rAUTH_LOGIN_UI\x10&\x12\x12\n\x0eUSER_DATA_EDIT\x10)\x12\x11\n\rCERTIFICATION\x10+\x12\x1b\n\x17\x43\x45RTIFICATION_ROOM_SHOW\x10,\x12%\n!CERTIFICATION_ROOM_WIN_OPEN_CLOSE\x10-\x12\x10\n\x0c\x43\x45RTIFY_WORD\x10.\x12\x11\n\rCERTIFY_CHAIR\x10/\x12\x1c\n\x18\x43\x45RTIFY_UPDATE_USER_INFO\x10\x30\x12\x1c\n\x18\x43\x45RTIFY_BROADCAST_FRIEND\x10\x31\x12\x15\n\x11\x43\x45RTIFY_HEAD_LINE\x10\x32\x12\x15\n\x11\x43\x45RTIFY_TIAO_TIAO\x10\x33\x12\x14\n\x10LOGIN_BIND_PHONE\x10\x34\x12\x1c\n\x18\x43\x45RTIFY_OWNER_ENTER_ROOM\x10\x35\x12\x0f\n\x0bYoung_Model\x10:\x12\x14\n\x10\x43USTOMER_SERVICE\x10;\x12\x15\n\x11OVERSEAS_IP_LIMIT\x10\x42\x12\x12\n\x0eOLD_NAME_LIMIT\x10\x43\x12\x12\n\x0e\x43RACK_SELF_MSG\x10\x44\x12\x12\n\x0eORDER_LOCATION\x10G\x12\x12\n\x0e\x44\x45LETE_ACCOUNT\x10I\x12\x0f\n\x0bYUNPIAN_SMS\x10J\x12\x11\n\rBIND_PHONE_V2\x10K\x12\x14\n\x10\x42IND_PHONE_LOGIN\x10L\x12\x0e\n\nCOUNT_DOWN\x10N\x12\x0e\n\nOXYGEN_BAR\x10^\x12\x13\n\x0fPRIVACY_SETTING\x10_\x12\x1f\n\x1bOXYGEN_BAR_CLAN_MEMBER_ONLY\x10`\x12\x18\n\x14OXYGEN_BAR_TREND_GIF\x10\x61\x12\x0e\n\nDATA_AUDIT\x10\x62\x12\r\n\tInner_Tec\x10\x64\x12\r\n\tInner_Ali\x10\x65\x12\x16\n\x12\x43\x45RTIFY_IM_PICTURE\x10g\x12\x0b\n\x07\x43MB_VIP\x10h\x12\x13\n\x0f\x43RACKEGG_FOREST\x10i\x12\x13\n\x0e\x41NTI_ADDICTION\x10\xc8\x01\x12&\n!TEXT_FILTER_ROOM_SCREEN_ENCRYPTED\x10\xc9\x01\x12(\n#TEXT_FILTER_ROOM_SCREEN_UNENCRYPTED\x10\xca\x01\x12!\n\x1cTEXT_FILTER_BROADCAST_FRIEND\x10\xcb\x01\x12\x1d\n\x18TEXT_FILTER_PRIVATE_CHAT\x10\xcc\x01\x12\x10\n\x0c\x42\x43_HEAD_LINE\x10n\x12\x13\n\x0fONE_CLICK_LOGIN\x10o\x12\x0e\n\nCERTIFY_PM\x10p\x12\x13\n\x0f\x43\x45RTIFY_PICTURE\x10q\x12\x19\n\x15\x43HANNEL_ADVERT_AUDITS\x10r\x12\x1a\n\x16\x43\x45RTIFY_CREATE_CHANNEL\x10t\x12\x18\n\x14\x43\x45RTIFY_JOIN_CHANNEL\x10u\x12\x10\n\x0c\x43\x45RTIFY_GIVE\x10v\x12\x17\n\x13\x43\x45RTIFY_ROOM_NOTICE\x10w\x12\x14\n\x10\x43\x45RTIFY_RECHARGE\x10x\x12\x19\n\x15\x43\x45RTIFY_PUBLISH_TREND\x10y\x12\x19\n\x15\x43\x45RTIFY_COMMENT_TREND\x10z\x12\x11\n\rHOME_NAV_TYPE\x10{\x12\x11\n\rLOGIN_CHECKED\x10|\x12\x0e\n\nHIGH_SOUND\x10}\x12\x16\n\x12HIGH_SOUND_CHANNEL\x10~\x12\x1a\n\x16\x43HANNEL_STAR_CHALLENGE\x10\x7f\x12\x11\n\x0c\x43HANNEL_STAT\x10\x80\x01\x12\x11\n\x0cREGISTER_SEX\x10\x82\x01\x12\x16\n\x11REGISTER_NICKNAME\x10\x83\x01\x12\x16\n\x11REGISTER_ATTITUDE\x10\x84\x01\x12\x13\n\x0e\x43REATE_CHANNEL\x10\x85\x01\x12\x1a\n\x15\x43OMMUNITY_TREND_AUDIO\x10\x86\x01\x12\x0c\n\x07IM_TIPS\x10\x87\x01\x12\x18\n\x13MULTI_CLIENT_ONLINE\x10\xfd\x01*)\n\nStatusCode\x12\x0b\n\x07SC_FAIL\x10\x00\x12\x0e\n\nSC_SUCCESS\x10\x01*?\n\nEffectType\x12\x12\n\x0e\x45\x66\x66\x65\x63tTypeNone\x10\x00\x12\x1d\n\x19\x45\x66\x66\x65\x63tTypeNicknamePendant\x10\x01*\x7f\n\x0e\x45\x66\x66\x65\x63tTimeType\x12\x18\n\x14\x45\x66\x66\x65\x63tTimeTypeAlways\x10\x00\x12\x16\n\x12\x45\x66\x66\x65\x63tTimeTypeMike\x10\x01\x12\x1e\n\x1a\x45\x66\x66\x65\x63tTimeTypeWearInPacket\x10\x02\x12\x1b\n\x17\x45\x66\x66\x65\x63tTimeTypePermanent\x10\x03*,\n\x0f\x45\x66\x66\x65\x63tUseStatus\x12\n\n\x06\x45S_Use\x10\x00\x12\r\n\tES_NotUse\x10\x01*I\n\x10\x45\x66\x66\x65\x63tNoticeType\x12\x18\n\x14\x45\x66\x66\x65\x63tNoticeTypeGain\x10\x00\x12\x1b\n\x17\x45\x66\x66\x65\x63tNoticeTypeTimeout\x10\x01*:\n\x10ModelOnOffStatus\x12\x0b\n\x07\x41LL_OFF\x10\x00\x12\n\n\x06\x41LL_ON\x10\x01\x12\r\n\tWHITELIST\x10\x02*A\n\x08RankType\x12\x0b\n\x07RT_ZERO\x10\x00\x12\x0c\n\x08RT_CHARM\x10\x01\x12\r\n\tRT_WEALTH\x10\x02\x12\x0b\n\x07RT_GIFT\x10\x03*N\n\rLoadClickType\x12\x0c\n\x08LCT_ZERO\x10\x00\x12\x17\n\x13LCT_INTIMATE_DETAIL\x10\x01\x12\x16\n\x12LCT_INTIMATE_STORE\x10\x02*F\n\x0b\x41uditStatus\x12\x11\n\rAS_Audit_Pass\x10\x00\x12\x0f\n\x0b\x41S_Auditing\x10\x01\x12\x13\n\x0f\x41S_Audit_Refuse\x10\x02*\xf3\x01\n\nUploadType\x12\x0c\n\x08TypeZero\x10\x00\x12\x10\n\x0cHeadAlbumImg\x10\x01\x12\x0f\n\x0bHeadIconImg\x10\x02\x12\x0f\n\x0b\x44ynamicsImg\x10\x03\x12\r\n\tClientLog\x10\x04\x12\x0e\n\nTipOffsImg\x10\x05\x12\x0c\n\x08Indetity\x10\x06\x12\x0b\n\x07PMMedia\x10\x07\x12\t\n\x05Voice\x10\x08\x12\x11\n\rBackgroundImg\x10\x17\x12\x0f\n\x0b\x43hannelIcon\x10\x18\x12\x11\n\rWXRobotQRcode\x10\x19\x12\x13\n\x0f\x43ommunityTagImg\x10\x1c\x12\x12\n\x0ePersonLabelImg\x10\x1d*\xe9\x01\n\x0ePayChannelType\x12\x0c\n\x08PCT_NULL\x10\x00\x12\x11\n\rPCT_ALIPAY_H5\x10\x02\x12\x12\n\x0ePCT_ALIPAY_APP\x10\x03\x12\x11\n\rPCT_WXPAY_APP\x10\x04\x12\x10\n\x0cPCT_WXPAY_H5\x10\x05\x12\x0b\n\x07PCT_IAP\x10\x06\x12\x0c\n\x08PCT_PLAY\x10\x08\x12\x0e\n\nPCT_PAYPAL\x10\n\x12\r\n\tPCT_BOING\x10\x0b\x12\x10\n\x0cPCT_UNIONPAY\x10\x0c\x12\x0e\n\tPCT_AGENT\x10\xfd\x01\x12\x0f\n\nPCT_MANUAL\x10\xfe\x01\x12\x10\n\x0bPCT_DEVTEST\x10\xff\x01*i\n\x04Role\x12\n\n\x06R_NONE\x10\x00\x12\x0f\n\x0bR_SUPERUSER\x10\x01\x12\x08\n\x04R_OW\x10\x02\x12\x08\n\x04R_VP\x10\x03\x12\x08\n\x04R_MA\x10\x04\x12\t\n\x05R_CA1\x10\x05\x12\t\n\x05R_CA2\x10\x06\x12\x07\n\x03R_R\x10\x07\x12\x07\n\x03R_U\x10\x08*]\n\x0eNameplateStyle\x12\x0b\n\x07NS_NONE\x10\x00\x12\x0e\n\nNS_STYLE_1\x10\x01\x12\x0e\n\nNS_STYLE_2\x10\x02\x12\x0e\n\nNS_STYLE_3\x10\x03\x12\x0e\n\nNS_STYLE_4\x10\x04*E\n\x12PlayerResourceType\x12\x0c\n\x08PRT_NONE\x10\x00\x12\x15\n\x11PRT_FIRST_ACCOUNT\x10\x01\x12\n\n\x06PRT_WX\x10\x02*f\n\x19\x41ttitudeDegreesStatusType\x12\x13\n\x0f\x41\x44ST_BOTH_EVERY\x10\x00\x12\x17\n\x13\x41\x44ST_OPPOSITE_EVERY\x10\x01\x12\x1b\n\x17\x41\x44ST_OPPOSITE_NOTENOUGH\x10\x02*u\n\nCMediaType\x12\x13\n\x0f\x43MediaType_None\x10\x00\x12\x12\n\x0e\x43MediaType_Png\x10\x01\x12\x12\n\x0e\x43MediaType_Gif\x10\x02\x12\x14\n\x10\x43MediaType_Video\x10\x03\x12\x14\n\x10\x43MediaType_Audio\x10\x04*w\n\x11\x44\x65viceConnectOper\x12\x0c\n\x08\x44\x43S_None\x10\x00\x12\x12\n\x0e\x44\x43S_Requesting\x10\x01\x12\x0f\n\x0b\x44\x43S_Receive\x10\x02\x12\x0e\n\nDCS_Refuse\x10\x03\x12\x0f\n\x0b\x44\x43S_Timeout\x10\x04\x12\x0e\n\nDCS_Cancel\x10\x05*\xa7\x01\n\x0b\x44\x65viceCmdId\x12\x11\n\rDC_DeviceZero\x10\x00\x12\x14\n\x0e\x44\x43_DeviceLogin\x10\x99\x98\x1f\x12\x1e\n\x18\x44\x43_MessageConnectOperate\x10\x9a\x98\x1f\x12\x1c\n\x16\x44\x43_MessageStatusUpdate\x10\x9b\x98\x1f\x12\x1a\n\x14\x44\x43_DeviceShareStatus\x10\x9c\x98\x1f\x12\x15\n\x0f\x44\x43_SingoConnect\x10\xb9\xa5%*L\n\nTaskStatus\x12\x0b\n\x07TS_None\x10\x00\x12\x11\n\rTS_Processing\x10\x01\x12\x0e\n\nTS_Success\x10\x02\x12\x0e\n\nTS_Failure\x10\x03*N\n\x08TaskType\x12\x0b\n\x07TT_None\x10\x00\x12\x0c\n\x08TT_Image\x10\x01\x12\x0c\n\x08TT_Video\x10\x02\x12\x0c\n\x08TT_Audio\x10\x03\x12\x0b\n\x07TT_Text\x10\x04*C\n\tLabelType\x12\x0b\n\x07LT_NONE\x10\x00\x12\x0b\n\x07LT_POST\x10\x01\x12\x0e\n\nLT_Gallery\x10\x02\x12\x0c\n\x08LT_Group\x10\x03*N\n\x08\x41igcType\x12\x0b\n\x07\x41T_NONE\x10\x00\x12\x0c\n\x08\x41T_IMAGE\x10\x01\x12\x0c\n\x08\x41T_VIDEO\x10\x02\x12\x0c\n\x08\x41T_AUDIO\x10\x03\x12\x0b\n\x07\x41T_TEXT\x10\x04\x42\x06\xa2\x02\x03PB3b\x06proto3')

_COMMONERR = DESCRIPTOR.enum_types_by_name['CommonErr']
CommonErr = enum_type_wrapper.EnumTypeWrapper(_COMMONERR)
_SEXTYPE = DESCRIPTOR.enum_types_by_name['SexType']
SexType = enum_type_wrapper.EnumTypeWrapper(_SEXTYPE)
_OWNERINROOM = DESCRIPTOR.enum_types_by_name['OwnerInRoom']
OwnerInRoom = enum_type_wrapper.EnumTypeWrapper(_OWNERINROOM)
_SCENETYPE = DESCRIPTOR.enum_types_by_name['SceneType']
SceneType = enum_type_wrapper.EnumTypeWrapper(_SCENETYPE)
_ROOMADMINTYPE = DESCRIPTOR.enum_types_by_name['RoomAdminType']
RoomAdminType = enum_type_wrapper.EnumTypeWrapper(_ROOMADMINTYPE)
_DEVICETYPE = DESCRIPTOR.enum_types_by_name['DeviceType']
DeviceType = enum_type_wrapper.EnumTypeWrapper(_DEVICETYPE)
_PLAYERFLAGS = DESCRIPTOR.enum_types_by_name['PlayerFlags']
PlayerFlags = enum_type_wrapper.EnumTypeWrapper(_PLAYERFLAGS)
_ACCOUNTFLAGS = DESCRIPTOR.enum_types_by_name['AccountFlags']
AccountFlags = enum_type_wrapper.EnumTypeWrapper(_ACCOUNTFLAGS)
_ONOFFTYPE = DESCRIPTOR.enum_types_by_name['OnOffType']
OnOffType = enum_type_wrapper.EnumTypeWrapper(_ONOFFTYPE)
_STATUSCODE = DESCRIPTOR.enum_types_by_name['StatusCode']
StatusCode = enum_type_wrapper.EnumTypeWrapper(_STATUSCODE)
_EFFECTTYPE = DESCRIPTOR.enum_types_by_name['EffectType']
EffectType = enum_type_wrapper.EnumTypeWrapper(_EFFECTTYPE)
_EFFECTTIMETYPE = DESCRIPTOR.enum_types_by_name['EffectTimeType']
EffectTimeType = enum_type_wrapper.EnumTypeWrapper(_EFFECTTIMETYPE)
_EFFECTUSESTATUS = DESCRIPTOR.enum_types_by_name['EffectUseStatus']
EffectUseStatus = enum_type_wrapper.EnumTypeWrapper(_EFFECTUSESTATUS)
_EFFECTNOTICETYPE = DESCRIPTOR.enum_types_by_name['EffectNoticeType']
EffectNoticeType = enum_type_wrapper.EnumTypeWrapper(_EFFECTNOTICETYPE)
_MODELONOFFSTATUS = DESCRIPTOR.enum_types_by_name['ModelOnOffStatus']
ModelOnOffStatus = enum_type_wrapper.EnumTypeWrapper(_MODELONOFFSTATUS)
_RANKTYPE = DESCRIPTOR.enum_types_by_name['RankType']
RankType = enum_type_wrapper.EnumTypeWrapper(_RANKTYPE)
_LOADCLICKTYPE = DESCRIPTOR.enum_types_by_name['LoadClickType']
LoadClickType = enum_type_wrapper.EnumTypeWrapper(_LOADCLICKTYPE)
_AUDITSTATUS = DESCRIPTOR.enum_types_by_name['AuditStatus']
AuditStatus = enum_type_wrapper.EnumTypeWrapper(_AUDITSTATUS)
_UPLOADTYPE = DESCRIPTOR.enum_types_by_name['UploadType']
UploadType = enum_type_wrapper.EnumTypeWrapper(_UPLOADTYPE)
_PAYCHANNELTYPE = DESCRIPTOR.enum_types_by_name['PayChannelType']
PayChannelType = enum_type_wrapper.EnumTypeWrapper(_PAYCHANNELTYPE)
_ROLE = DESCRIPTOR.enum_types_by_name['Role']
Role = enum_type_wrapper.EnumTypeWrapper(_ROLE)
_NAMEPLATESTYLE = DESCRIPTOR.enum_types_by_name['NameplateStyle']
NameplateStyle = enum_type_wrapper.EnumTypeWrapper(_NAMEPLATESTYLE)
_PLAYERRESOURCETYPE = DESCRIPTOR.enum_types_by_name['PlayerResourceType']
PlayerResourceType = enum_type_wrapper.EnumTypeWrapper(_PLAYERRESOURCETYPE)
_ATTITUDEDEGREESSTATUSTYPE = DESCRIPTOR.enum_types_by_name['AttitudeDegreesStatusType']
AttitudeDegreesStatusType = enum_type_wrapper.EnumTypeWrapper(_ATTITUDEDEGREESSTATUSTYPE)
_CMEDIATYPE = DESCRIPTOR.enum_types_by_name['CMediaType']
CMediaType = enum_type_wrapper.EnumTypeWrapper(_CMEDIATYPE)
_DEVICECONNECTOPER = DESCRIPTOR.enum_types_by_name['DeviceConnectOper']
DeviceConnectOper = enum_type_wrapper.EnumTypeWrapper(_DEVICECONNECTOPER)
_DEVICECMDID = DESCRIPTOR.enum_types_by_name['DeviceCmdId']
DeviceCmdId = enum_type_wrapper.EnumTypeWrapper(_DEVICECMDID)
_TASKSTATUS = DESCRIPTOR.enum_types_by_name['TaskStatus']
TaskStatus = enum_type_wrapper.EnumTypeWrapper(_TASKSTATUS)
_TASKTYPE = DESCRIPTOR.enum_types_by_name['TaskType']
TaskType = enum_type_wrapper.EnumTypeWrapper(_TASKTYPE)
_LABELTYPE = DESCRIPTOR.enum_types_by_name['LabelType']
LabelType = enum_type_wrapper.EnumTypeWrapper(_LABELTYPE)
_AIGCTYPE = DESCRIPTOR.enum_types_by_name['AigcType']
AigcType = enum_type_wrapper.EnumTypeWrapper(_AIGCTYPE)
ErrCodeNone = 0
ErrCodeRedis = 10001
ErrCodeMysql = 10002
ErrCodeFrequency = 10003
ErrCodeParam = 10004
ErrCodeNoMatchObj = 10005
ErrCodeBusy = 10006
ErrCodeMaintain = 16666
UNKNOWN = 0
MALE = 1
FEMALE = 2
NotInSelfRoom = 0
InSelfRoom = 1
ST_ZERO = 0
ST_HOME = 1
RAT_GUEST = 0
RAT_NORMAL = 10
RAT_ADMIN = 20
RAT_OWNER = 30
RAT_SUPER_ADMIN = 40
RAT_BLACK = -5
DT_UNKNOWN = 0
DT_FLASHPLAYER = 1
DT_ANDROID_PHONE = 20
DT_IOS_PHONE = 40
DT_WINDOWS_ASSISTANT = 80
DT_WINDOWS_PC = 90
DT_ROBOT = 100
DT_WECHAT_SUBSCRIPTION = 110
DT_QQ_SMALL_PROGRAM = 120
DT_WX_MINI_PROGRAM = 130
DT_WEB = 140
DT_MAC = 150
PF_ZERO = 0
PF_CERTIFICATION = 1
PF_BIND_BANK = 4
PF_INVITE = 5
PF_CHARGE_FIRST = 12
PF_ATTITUDE_QUESTION = 13
PF_END_REGISTRATION = 14
AF_ZERO = 0
AF_PHONE_VERIFIED = 1
YEAR_BAG = 0
CRACK_EGG = 1
GOOGLE_PAY = 5
IAP_PAY = 6
INVITE = 7
INDEX_CATEGORY = 8
CERTIF = 9
GUARD = 10
LOTTERY_DRAW = 12
MENTOR_SHIP = 13
CERTIF_IOS = 14
REAL_IDENTITY = 15
NOVICE_GIFT = 16
ROOM_SET_MODEL = 18
ACTIVITY_TYPE = 20
ACTIVITY = 21
HOT_SONG = 23
ROOM_ENTER = 34
ROOM_PATTERN_HIGH_QUALITY = 35
AUTH_LOGIN_UI = 38
USER_DATA_EDIT = 41
CERTIFICATION = 43
CERTIFICATION_ROOM_SHOW = 44
CERTIFICATION_ROOM_WIN_OPEN_CLOSE = 45
CERTIFY_WORD = 46
CERTIFY_CHAIR = 47
CERTIFY_UPDATE_USER_INFO = 48
CERTIFY_BROADCAST_FRIEND = 49
CERTIFY_HEAD_LINE = 50
CERTIFY_TIAO_TIAO = 51
LOGIN_BIND_PHONE = 52
CERTIFY_OWNER_ENTER_ROOM = 53
Young_Model = 58
CUSTOMER_SERVICE = 59
OVERSEAS_IP_LIMIT = 66
OLD_NAME_LIMIT = 67
CRACK_SELF_MSG = 68
ORDER_LOCATION = 71
DELETE_ACCOUNT = 73
YUNPIAN_SMS = 74
BIND_PHONE_V2 = 75
BIND_PHONE_LOGIN = 76
COUNT_DOWN = 78
OXYGEN_BAR = 94
PRIVACY_SETTING = 95
OXYGEN_BAR_CLAN_MEMBER_ONLY = 96
OXYGEN_BAR_TREND_GIF = 97
DATA_AUDIT = 98
Inner_Tec = 100
Inner_Ali = 101
CERTIFY_IM_PICTURE = 103
CMB_VIP = 104
CRACKEGG_FOREST = 105
ANTI_ADDICTION = 200
TEXT_FILTER_ROOM_SCREEN_ENCRYPTED = 201
TEXT_FILTER_ROOM_SCREEN_UNENCRYPTED = 202
TEXT_FILTER_BROADCAST_FRIEND = 203
TEXT_FILTER_PRIVATE_CHAT = 204
BC_HEAD_LINE = 110
ONE_CLICK_LOGIN = 111
CERTIFY_PM = 112
CERTIFY_PICTURE = 113
CHANNEL_ADVERT_AUDITS = 114
CERTIFY_CREATE_CHANNEL = 116
CERTIFY_JOIN_CHANNEL = 117
CERTIFY_GIVE = 118
CERTIFY_ROOM_NOTICE = 119
CERTIFY_RECHARGE = 120
CERTIFY_PUBLISH_TREND = 121
CERTIFY_COMMENT_TREND = 122
HOME_NAV_TYPE = 123
LOGIN_CHECKED = 124
HIGH_SOUND = 125
HIGH_SOUND_CHANNEL = 126
CHANNEL_STAR_CHALLENGE = 127
CHANNEL_STAT = 128
REGISTER_SEX = 130
REGISTER_NICKNAME = 131
REGISTER_ATTITUDE = 132
CREATE_CHANNEL = 133
COMMUNITY_TREND_AUDIO = 134
IM_TIPS = 135
MULTI_CLIENT_ONLINE = 253
SC_FAIL = 0
SC_SUCCESS = 1
EffectTypeNone = 0
EffectTypeNicknamePendant = 1
EffectTimeTypeAlways = 0
EffectTimeTypeMike = 1
EffectTimeTypeWearInPacket = 2
EffectTimeTypePermanent = 3
ES_Use = 0
ES_NotUse = 1
EffectNoticeTypeGain = 0
EffectNoticeTypeTimeout = 1
ALL_OFF = 0
ALL_ON = 1
WHITELIST = 2
RT_ZERO = 0
RT_CHARM = 1
RT_WEALTH = 2
RT_GIFT = 3
LCT_ZERO = 0
LCT_INTIMATE_DETAIL = 1
LCT_INTIMATE_STORE = 2
AS_Audit_Pass = 0
AS_Auditing = 1
AS_Audit_Refuse = 2
TypeZero = 0
HeadAlbumImg = 1
HeadIconImg = 2
DynamicsImg = 3
ClientLog = 4
TipOffsImg = 5
Indetity = 6
PMMedia = 7
Voice = 8
BackgroundImg = 23
ChannelIcon = 24
WXRobotQRcode = 25
CommunityTagImg = 28
PersonLabelImg = 29
PCT_NULL = 0
PCT_ALIPAY_H5 = 2
PCT_ALIPAY_APP = 3
PCT_WXPAY_APP = 4
PCT_WXPAY_H5 = 5
PCT_IAP = 6
PCT_PLAY = 8
PCT_PAYPAL = 10
PCT_BOING = 11
PCT_UNIONPAY = 12
PCT_AGENT = 253
PCT_MANUAL = 254
PCT_DEVTEST = 255
R_NONE = 0
R_SUPERUSER = 1
R_OW = 2
R_VP = 3
R_MA = 4
R_CA1 = 5
R_CA2 = 6
R_R = 7
R_U = 8
NS_NONE = 0
NS_STYLE_1 = 1
NS_STYLE_2 = 2
NS_STYLE_3 = 3
NS_STYLE_4 = 4
PRT_NONE = 0
PRT_FIRST_ACCOUNT = 1
PRT_WX = 2
ADST_BOTH_EVERY = 0
ADST_OPPOSITE_EVERY = 1
ADST_OPPOSITE_NOTENOUGH = 2
CMediaType_None = 0
CMediaType_Png = 1
CMediaType_Gif = 2
CMediaType_Video = 3
CMediaType_Audio = 4
DCS_None = 0
DCS_Requesting = 1
DCS_Receive = 2
DCS_Refuse = 3
DCS_Timeout = 4
DCS_Cancel = 5
DC_DeviceZero = 0
DC_DeviceLogin = 511001
DC_MessageConnectOperate = 511002
DC_MessageStatusUpdate = 511003
DC_DeviceShareStatus = 511004
DC_SingoConnect = 611001
TS_None = 0
TS_Processing = 1
TS_Success = 2
TS_Failure = 3
TT_None = 0
TT_Image = 1
TT_Video = 2
TT_Audio = 3
TT_Text = 4
LT_NONE = 0
LT_POST = 1
LT_Gallery = 2
LT_Group = 3
AT_NONE = 0
AT_IMAGE = 1
AT_VIDEO = 2
AT_AUDIO = 3
AT_TEXT = 4


_PLAYER = DESCRIPTOR.message_types_by_name['Player']
_USERINFO = DESCRIPTOR.message_types_by_name['UserInfo']
_PLAYERINFO = DESCRIPTOR.message_types_by_name['PlayerInfo']
_BAGITEM = DESCRIPTOR.message_types_by_name['BagItem']
_AGODAKEY = DESCRIPTOR.message_types_by_name['AgodaKey']
_ONOFFSTATUS = DESCRIPTOR.message_types_by_name['OnOffStatus']
_SEARCHPLAYERENTRY = DESCRIPTOR.message_types_by_name['SearchPlayerEntry']
_EFFECTINFO = DESCRIPTOR.message_types_by_name['EffectInfo']
_EFFECT = DESCRIPTOR.message_types_by_name['Effect']
_EFFECTCONFIG = DESCRIPTOR.message_types_by_name['EffectConfig']
_EFFECTNICKNAMEPENDANT = DESCRIPTOR.message_types_by_name['EffectNicknamePendant']
_EFFECTSERCONF = DESCRIPTOR.message_types_by_name['EffectSerConf']
_INDEXTIPROOMS = DESCRIPTOR.message_types_by_name['IndexTipRooms']
_REGISID = DESCRIPTOR.message_types_by_name['RegisId']
_MODELONOFF = DESCRIPTOR.message_types_by_name['ModelOnOff']
_RANK = DESCRIPTOR.message_types_by_name['Rank']
_PLAYERCHAIRROOM = DESCRIPTOR.message_types_by_name['PlayerChairRoom']
_CLANINFO = DESCRIPTOR.message_types_by_name['ClanInfo']
_PERIOD = DESCRIPTOR.message_types_by_name['Period']
_LABELINFO = DESCRIPTOR.message_types_by_name['LabelInfo']
_PLAYERRESOURCESHORT = DESCRIPTOR.message_types_by_name['PlayerResourceShort']
_PLAYERRESOURCE = DESCRIPTOR.message_types_by_name['PlayerResource']
_PLAYERRESOURCEWITHSCORE = DESCRIPTOR.message_types_by_name['PlayerResourceWithScore']
_ATTITUDEDEGREESINFO = DESCRIPTOR.message_types_by_name['AttitudeDegreesInfo']
_ATTITUDECATEGORYDEGREESINFO = DESCRIPTOR.message_types_by_name['AttitudeCategoryDegreesInfo']
_CMEDIARESOURCE = DESCRIPTOR.message_types_by_name['CMediaResource']
_SAYHELLOREQ = DESCRIPTOR.message_types_by_name['SayHelloReq']
_SAYHELLORES = DESCRIPTOR.message_types_by_name['SayHelloRes']
_HEARTBEATREQ = DESCRIPTOR.message_types_by_name['HeartbeatReq']
_HEARTBEATRES = DESCRIPTOR.message_types_by_name['HeartbeatRes']
Player = _reflection.GeneratedProtocolMessageType('Player', (_message.Message,), {
  'DESCRIPTOR' : _PLAYER,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.Player)
  })
_sym_db.RegisterMessage(Player)

UserInfo = _reflection.GeneratedProtocolMessageType('UserInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERINFO,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.UserInfo)
  })
_sym_db.RegisterMessage(UserInfo)

PlayerInfo = _reflection.GeneratedProtocolMessageType('PlayerInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERINFO,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.PlayerInfo)
  })
_sym_db.RegisterMessage(PlayerInfo)

BagItem = _reflection.GeneratedProtocolMessageType('BagItem', (_message.Message,), {
  'DESCRIPTOR' : _BAGITEM,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.BagItem)
  })
_sym_db.RegisterMessage(BagItem)

AgodaKey = _reflection.GeneratedProtocolMessageType('AgodaKey', (_message.Message,), {
  'DESCRIPTOR' : _AGODAKEY,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AgodaKey)
  })
_sym_db.RegisterMessage(AgodaKey)

OnOffStatus = _reflection.GeneratedProtocolMessageType('OnOffStatus', (_message.Message,), {
  'DESCRIPTOR' : _ONOFFSTATUS,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.OnOffStatus)
  })
_sym_db.RegisterMessage(OnOffStatus)

SearchPlayerEntry = _reflection.GeneratedProtocolMessageType('SearchPlayerEntry', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHPLAYERENTRY,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.SearchPlayerEntry)
  })
_sym_db.RegisterMessage(SearchPlayerEntry)

EffectInfo = _reflection.GeneratedProtocolMessageType('EffectInfo', (_message.Message,), {
  'DESCRIPTOR' : _EFFECTINFO,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.EffectInfo)
  })
_sym_db.RegisterMessage(EffectInfo)

Effect = _reflection.GeneratedProtocolMessageType('Effect', (_message.Message,), {
  'DESCRIPTOR' : _EFFECT,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.Effect)
  })
_sym_db.RegisterMessage(Effect)

EffectConfig = _reflection.GeneratedProtocolMessageType('EffectConfig', (_message.Message,), {
  'DESCRIPTOR' : _EFFECTCONFIG,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.EffectConfig)
  })
_sym_db.RegisterMessage(EffectConfig)

EffectNicknamePendant = _reflection.GeneratedProtocolMessageType('EffectNicknamePendant', (_message.Message,), {
  'DESCRIPTOR' : _EFFECTNICKNAMEPENDANT,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.EffectNicknamePendant)
  })
_sym_db.RegisterMessage(EffectNicknamePendant)

EffectSerConf = _reflection.GeneratedProtocolMessageType('EffectSerConf', (_message.Message,), {
  'DESCRIPTOR' : _EFFECTSERCONF,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.EffectSerConf)
  })
_sym_db.RegisterMessage(EffectSerConf)

IndexTipRooms = _reflection.GeneratedProtocolMessageType('IndexTipRooms', (_message.Message,), {
  'DESCRIPTOR' : _INDEXTIPROOMS,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.IndexTipRooms)
  })
_sym_db.RegisterMessage(IndexTipRooms)

RegisId = _reflection.GeneratedProtocolMessageType('RegisId', (_message.Message,), {
  'DESCRIPTOR' : _REGISID,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.RegisId)
  })
_sym_db.RegisterMessage(RegisId)

ModelOnOff = _reflection.GeneratedProtocolMessageType('ModelOnOff', (_message.Message,), {
  'DESCRIPTOR' : _MODELONOFF,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.ModelOnOff)
  })
_sym_db.RegisterMessage(ModelOnOff)

Rank = _reflection.GeneratedProtocolMessageType('Rank', (_message.Message,), {
  'DESCRIPTOR' : _RANK,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.Rank)
  })
_sym_db.RegisterMessage(Rank)

PlayerChairRoom = _reflection.GeneratedProtocolMessageType('PlayerChairRoom', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERCHAIRROOM,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.PlayerChairRoom)
  })
_sym_db.RegisterMessage(PlayerChairRoom)

ClanInfo = _reflection.GeneratedProtocolMessageType('ClanInfo', (_message.Message,), {
  'DESCRIPTOR' : _CLANINFO,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.ClanInfo)
  })
_sym_db.RegisterMessage(ClanInfo)

Period = _reflection.GeneratedProtocolMessageType('Period', (_message.Message,), {
  'DESCRIPTOR' : _PERIOD,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.Period)
  })
_sym_db.RegisterMessage(Period)

LabelInfo = _reflection.GeneratedProtocolMessageType('LabelInfo', (_message.Message,), {
  'DESCRIPTOR' : _LABELINFO,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.LabelInfo)
  })
_sym_db.RegisterMessage(LabelInfo)

PlayerResourceShort = _reflection.GeneratedProtocolMessageType('PlayerResourceShort', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERRESOURCESHORT,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.PlayerResourceShort)
  })
_sym_db.RegisterMessage(PlayerResourceShort)

PlayerResource = _reflection.GeneratedProtocolMessageType('PlayerResource', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERRESOURCE,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.PlayerResource)
  })
_sym_db.RegisterMessage(PlayerResource)

PlayerResourceWithScore = _reflection.GeneratedProtocolMessageType('PlayerResourceWithScore', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERRESOURCEWITHSCORE,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.PlayerResourceWithScore)
  })
_sym_db.RegisterMessage(PlayerResourceWithScore)

AttitudeDegreesInfo = _reflection.GeneratedProtocolMessageType('AttitudeDegreesInfo', (_message.Message,), {
  'DESCRIPTOR' : _ATTITUDEDEGREESINFO,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AttitudeDegreesInfo)
  })
_sym_db.RegisterMessage(AttitudeDegreesInfo)

AttitudeCategoryDegreesInfo = _reflection.GeneratedProtocolMessageType('AttitudeCategoryDegreesInfo', (_message.Message,), {
  'DESCRIPTOR' : _ATTITUDECATEGORYDEGREESINFO,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AttitudeCategoryDegreesInfo)
  })
_sym_db.RegisterMessage(AttitudeCategoryDegreesInfo)

CMediaResource = _reflection.GeneratedProtocolMessageType('CMediaResource', (_message.Message,), {
  'DESCRIPTOR' : _CMEDIARESOURCE,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.CMediaResource)
  })
_sym_db.RegisterMessage(CMediaResource)

SayHelloReq = _reflection.GeneratedProtocolMessageType('SayHelloReq', (_message.Message,), {
  'DESCRIPTOR' : _SAYHELLOREQ,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.SayHelloReq)
  })
_sym_db.RegisterMessage(SayHelloReq)

SayHelloRes = _reflection.GeneratedProtocolMessageType('SayHelloRes', (_message.Message,), {
  'DESCRIPTOR' : _SAYHELLORES,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.SayHelloRes)
  })
_sym_db.RegisterMessage(SayHelloRes)

HeartbeatReq = _reflection.GeneratedProtocolMessageType('HeartbeatReq', (_message.Message,), {
  'DESCRIPTOR' : _HEARTBEATREQ,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.HeartbeatReq)
  })
_sym_db.RegisterMessage(HeartbeatReq)

HeartbeatRes = _reflection.GeneratedProtocolMessageType('HeartbeatRes', (_message.Message,), {
  'DESCRIPTOR' : _HEARTBEATRES,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.HeartbeatRes)
  })
_sym_db.RegisterMessage(HeartbeatRes)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\242\002\003PB3'
  _COMMONERR._serialized_start=3470
  _COMMONERR._serialized_end=3643
  _SEXTYPE._serialized_start=3645
  _SEXTYPE._serialized_end=3689
  _OWNERINROOM._serialized_start=3691
  _OWNERINROOM._serialized_end=3739
  _SCENETYPE._serialized_start=3741
  _SCENETYPE._serialized_end=3778
  _ROOMADMINTYPE._serialized_start=3780
  _ROOMADMINTYPE._serialized_end=3901
  _DEVICETYPE._serialized_start=3904
  _DEVICETYPE._serialized_end=4155
  _PLAYERFLAGS._serialized_start=4158
  _PLAYERFLAGS._serialized_end=4311
  _ACCOUNTFLAGS._serialized_start=4313
  _ACCOUNTFLAGS._serialized_end=4363
  _ONOFFTYPE._serialized_start=4366
  _ONOFFTYPE._serialized_end=6154
  _STATUSCODE._serialized_start=6156
  _STATUSCODE._serialized_end=6197
  _EFFECTTYPE._serialized_start=6199
  _EFFECTTYPE._serialized_end=6262
  _EFFECTTIMETYPE._serialized_start=6264
  _EFFECTTIMETYPE._serialized_end=6391
  _EFFECTUSESTATUS._serialized_start=6393
  _EFFECTUSESTATUS._serialized_end=6437
  _EFFECTNOTICETYPE._serialized_start=6439
  _EFFECTNOTICETYPE._serialized_end=6512
  _MODELONOFFSTATUS._serialized_start=6514
  _MODELONOFFSTATUS._serialized_end=6572
  _RANKTYPE._serialized_start=6574
  _RANKTYPE._serialized_end=6639
  _LOADCLICKTYPE._serialized_start=6641
  _LOADCLICKTYPE._serialized_end=6719
  _AUDITSTATUS._serialized_start=6721
  _AUDITSTATUS._serialized_end=6791
  _UPLOADTYPE._serialized_start=6794
  _UPLOADTYPE._serialized_end=7037
  _PAYCHANNELTYPE._serialized_start=7040
  _PAYCHANNELTYPE._serialized_end=7273
  _ROLE._serialized_start=7275
  _ROLE._serialized_end=7380
  _NAMEPLATESTYLE._serialized_start=7382
  _NAMEPLATESTYLE._serialized_end=7475
  _PLAYERRESOURCETYPE._serialized_start=7477
  _PLAYERRESOURCETYPE._serialized_end=7546
  _ATTITUDEDEGREESSTATUSTYPE._serialized_start=7548
  _ATTITUDEDEGREESSTATUSTYPE._serialized_end=7650
  _CMEDIATYPE._serialized_start=7652
  _CMEDIATYPE._serialized_end=7769
  _DEVICECONNECTOPER._serialized_start=7771
  _DEVICECONNECTOPER._serialized_end=7890
  _DEVICECMDID._serialized_start=7893
  _DEVICECMDID._serialized_end=8060
  _TASKSTATUS._serialized_start=8062
  _TASKSTATUS._serialized_end=8138
  _TASKTYPE._serialized_start=8140
  _TASKTYPE._serialized_end=8218
  _LABELTYPE._serialized_start=8220
  _LABELTYPE._serialized_end=8287
  _AIGCTYPE._serialized_start=8289
  _AIGCTYPE._serialized_end=8367
  _PLAYER._serialized_start=25
  _PLAYER._serialized_end=400
  _USERINFO._serialized_start=403
  _USERINFO._serialized_end=532
  _PLAYERINFO._serialized_start=535
  _PLAYERINFO._serialized_end=878
  _BAGITEM._serialized_start=880
  _BAGITEM._serialized_end=941
  _AGODAKEY._serialized_start=943
  _AGODAKEY._serialized_end=977
  _ONOFFSTATUS._serialized_start=979
  _ONOFFSTATUS._serialized_end=1037
  _SEARCHPLAYERENTRY._serialized_start=1040
  _SEARCHPLAYERENTRY._serialized_end=1288
  _EFFECTINFO._serialized_start=1291
  _EFFECTINFO._serialized_end=1450
  _EFFECT._serialized_start=1453
  _EFFECT._serialized_end=1628
  _EFFECTCONFIG._serialized_start=1630
  _EFFECTCONFIG._serialized_end=1714
  _EFFECTNICKNAMEPENDANT._serialized_start=1716
  _EFFECTNICKNAMEPENDANT._serialized_end=1770
  _EFFECTSERCONF._serialized_start=1772
  _EFFECTSERCONF._serialized_end=1843
  _INDEXTIPROOMS._serialized_start=1845
  _INDEXTIPROOMS._serialized_end=1893
  _REGISID._serialized_start=1895
  _REGISID._serialized_end=1956
  _MODELONOFF._serialized_start=1958
  _MODELONOFF._serialized_end=2038
  _RANK._serialized_start=2041
  _RANK._serialized_end=2249
  _PLAYERCHAIRROOM._serialized_start=2251
  _PLAYERCHAIRROOM._serialized_end=2304
  _CLANINFO._serialized_start=2306
  _CLANINFO._serialized_end=2414
  _PERIOD._serialized_start=2416
  _PERIOD._serialized_end=2458
  _LABELINFO._serialized_start=2460
  _LABELINFO._serialized_end=2504
  _PLAYERRESOURCESHORT._serialized_start=2506
  _PLAYERRESOURCESHORT._serialized_end=2595
  _PLAYERRESOURCE._serialized_start=2598
  _PLAYERRESOURCE._serialized_end=2748
  _PLAYERRESOURCEWITHSCORE._serialized_start=2750
  _PLAYERRESOURCEWITHSCORE._serialized_end=2849
  _ATTITUDEDEGREESINFO._serialized_start=2852
  _ATTITUDEDEGREESINFO._serialized_end=3032
  _ATTITUDECATEGORYDEGREESINFO._serialized_start=3034
  _ATTITUDECATEGORYDEGREESINFO._serialized_end=3137
  _CMEDIARESOURCE._serialized_start=3140
  _CMEDIARESOURCE._serialized_end=3273
  _SAYHELLOREQ._serialized_start=3275
  _SAYHELLOREQ._serialized_end=3302
  _SAYHELLORES._serialized_start=3304
  _SAYHELLORES._serialized_end=3332
  _HEARTBEATREQ._serialized_start=3334
  _HEARTBEATREQ._serialized_end=3432
  _HEARTBEATRES._serialized_start=3434
  _HEARTBEATRES._serialized_end=3467
# @@protoc_insertion_point(module_scope)
