# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: user_status_ext.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from mecord import common_ext_pb2 as common__ext__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15user_status_ext.proto\x12\x02pb\x1a\x10\x63ommon_ext.proto\"a\n\x08LoginReq\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\ndeviceType\x18\x02 \x01(\x0e\x32\x0e.pb.DeviceType\x12\x10\n\x08\x64\x65viceId\x18\x03 \x01(\t\x12\x12\n\npush_token\x18\x04 \x01(\t\"\x1e\n\x08LoginRes\x12\x12\n\naccount_id\x18\x01 \x01(\x12\"_\n\x10\x42roadcastRelogin\x12\x10\n\x08\x64\x65viceId\x18\x01 \x01(\t\x12#\n\x0b\x64\x65vice_type\x18\x02 \x01(\x0e\x32\x0e.pb.DeviceType\x12\x14\n\x0cmulti_client\x18\x03 \x01(\x08\"5\n\x12\x42roadcastTakeLeave\x12\x12\n\naccount_id\x18\x01 \x01(\x12\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\x7f\n\x1b\x42roadcastDeviceDisconnected\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12#\n\x0b\x64\x65vice_type\x18\x02 \x01(\x0e\x32\x0e.pb.DeviceType\x12(\n\x06reason\x18\x03 \x01(\x0e\x32\x18.pb.DisconnectReasonType\"?\n\tLogoutReq\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x11\n\taccountId\x18\x02 \x01(\x03\x12\x12\n\ndeviceCode\x18\x03 \x01(\x03\"\x0b\n\tLogoutRes\"/\n\rDisconnectReq\x12\x0e\n\x06\x63onnId\x18\x01 \x01(\x12\x12\x0e\n\x06userId\x18\x02 \x01(\x12\"\x0f\n\rDisconnectRes\"\x14\n\x12UserConInfoListReq\"3\n\x12UserConInfoListRes\x12\x1d\n\x04list\x18\x01 \x03(\x0b\x32\x0f.pb.UserConInfo\"\x97\x01\n\x0bUserConInfo\x12\n\n\x02id\x18\x01 \x01(\x12\x12\n\n\x02ip\x18\x02 \x01(\t\x12#\n\x0b\x64\x65vice_type\x18\x03 \x01(\x0e\x32\x0e.pb.DeviceType\x12\x11\n\tdevice_id\x18\x04 \x01(\t\x12\x10\n\x08\x64ie_time\x18\x05 \x01(\x12\x12\x11\n\tplayer_id\x18\x06 \x01(\x12\x12\x13\n\x0b\x63reate_time\x18\x07 \x01(\x12\"S\n\x19UserDeviceDisconnectedReq\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12#\n\x0b\x64\x65vice_type\x18\x02 \x01(\x0e\x32\x0e.pb.DeviceType\"\x1b\n\x19UserDeviceDisconnectedRes\"f\n\x1bNotifyDeviceDisconnectedReq\x12\x10\n\x08phone_no\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12&\n\x04type\x18\x03 \x01(\x0e\x32\x18.pb.DisconnectReasonType\"\x1d\n\x1bNotifyDeviceDisconnectedRes*\xdc\x01\n\rUserStatusErr\x12\x15\n\x11UserStatusSUCCESS\x10\x00\x12\x1d\n\x17\x45rrUserStatusKeyExpired\x10\x89\xa1\x02\x12\x1d\n\x17\x45rrUserStatusBanAccount\x10\x8a\xa1\x02\x12\x18\n\x12\x45rrUserStatusBanIp\x10\x8b\xa1\x02\x12\x1a\n\x14\x45rrUserStatusRelogin\x10\x8c\xa1\x02\x12\x1c\n\x16\x45rrUserStatusTakeLeave\x10\x8d\xa1\x02\x12\"\n\x1c\x45rrUserStatusAccountDeleting\x10\x92\xa1\x02*\x89\x01\n\x0fUserStatusCmdId\x12\x15\n\x11UC_UserStatusZero\x10\x00\x12\x1a\n\x14UC_UserStatusRelogin\x10\x89\xca\x1e\x12\x1c\n\x16UC_UserStatusTakeLeave\x10\x8a\xca\x1e\x12%\n\x1fUC_UserStatusDeviceDisconnected\x10\x8b\xca\x1e*\x98\x01\n\x14\x44isconnectReasonType\x12\x0c\n\x08\x44RT_None\x10\x00\x12\x14\n\x10\x44RT_RefreshState\x10\x01\x12\x14\n\x10\x44RT_RemoveDevice\x10\x02\x12\x0b\n\x07\x44RT_Ban\x10\x03\x12\x12\n\x0e\x44RT_DelAccount\x10\x04\x12\x11\n\rDRT_ResetPass\x10\x05\x12\x12\n\x0e\x44RT_ModifyPass\x10\x06\x32\xc6\x03\n\x10UserStatusExtObj\x12#\n\x05Login\x12\x0c.pb.LoginReq\x1a\x0c.pb.LoginRes\x12&\n\x06Logout\x12\r.pb.LogoutReq\x1a\r.pb.LogoutRes\x12\x38\n\x10NotifyDisConnect\x12\x11.pb.DisconnectReq\x1a\x11.pb.DisconnectRes\x12/\n\tHeartbeat\x12\x10.pb.HeartbeatReq\x1a\x10.pb.HeartbeatRes\x12\x41\n\x0fUserConInfoList\x12\x16.pb.UserConInfoListReq\x1a\x16.pb.UserConInfoListRes\x12V\n\x16UserDeviceDisconnected\x12\x1d.pb.UserDeviceDisconnectedReq\x1a\x1d.pb.UserDeviceDisconnectedRes\x12_\n\x1bGetNotifyDeviceDisconnected\x12\x1f.pb.NotifyDeviceDisconnectedReq\x1a\x1f.pb.NotifyDeviceDisconnectedResB\x06\xa2\x02\x03PB3b\x06proto3')

_USERSTATUSERR = DESCRIPTOR.enum_types_by_name['UserStatusErr']
UserStatusErr = enum_type_wrapper.EnumTypeWrapper(_USERSTATUSERR)
_USERSTATUSCMDID = DESCRIPTOR.enum_types_by_name['UserStatusCmdId']
UserStatusCmdId = enum_type_wrapper.EnumTypeWrapper(_USERSTATUSCMDID)
_DISCONNECTREASONTYPE = DESCRIPTOR.enum_types_by_name['DisconnectReasonType']
DisconnectReasonType = enum_type_wrapper.EnumTypeWrapper(_DISCONNECTREASONTYPE)
UserStatusSUCCESS = 0
ErrUserStatusKeyExpired = 37001
ErrUserStatusBanAccount = 37002
ErrUserStatusBanIp = 37003
ErrUserStatusRelogin = 37004
ErrUserStatusTakeLeave = 37005
ErrUserStatusAccountDeleting = 37010
UC_UserStatusZero = 0
UC_UserStatusRelogin = 501001
UC_UserStatusTakeLeave = 501002
UC_UserStatusDeviceDisconnected = 501003
DRT_None = 0
DRT_RefreshState = 1
DRT_RemoveDevice = 2
DRT_Ban = 3
DRT_DelAccount = 4
DRT_ResetPass = 5
DRT_ModifyPass = 6


_LOGINREQ = DESCRIPTOR.message_types_by_name['LoginReq']
_LOGINRES = DESCRIPTOR.message_types_by_name['LoginRes']
_BROADCASTRELOGIN = DESCRIPTOR.message_types_by_name['BroadcastRelogin']
_BROADCASTTAKELEAVE = DESCRIPTOR.message_types_by_name['BroadcastTakeLeave']
_BROADCASTDEVICEDISCONNECTED = DESCRIPTOR.message_types_by_name['BroadcastDeviceDisconnected']
_LOGOUTREQ = DESCRIPTOR.message_types_by_name['LogoutReq']
_LOGOUTRES = DESCRIPTOR.message_types_by_name['LogoutRes']
_DISCONNECTREQ = DESCRIPTOR.message_types_by_name['DisconnectReq']
_DISCONNECTRES = DESCRIPTOR.message_types_by_name['DisconnectRes']
_USERCONINFOLISTREQ = DESCRIPTOR.message_types_by_name['UserConInfoListReq']
_USERCONINFOLISTRES = DESCRIPTOR.message_types_by_name['UserConInfoListRes']
_USERCONINFO = DESCRIPTOR.message_types_by_name['UserConInfo']
_USERDEVICEDISCONNECTEDREQ = DESCRIPTOR.message_types_by_name['UserDeviceDisconnectedReq']
_USERDEVICEDISCONNECTEDRES = DESCRIPTOR.message_types_by_name['UserDeviceDisconnectedRes']
_NOTIFYDEVICEDISCONNECTEDREQ = DESCRIPTOR.message_types_by_name['NotifyDeviceDisconnectedReq']
_NOTIFYDEVICEDISCONNECTEDRES = DESCRIPTOR.message_types_by_name['NotifyDeviceDisconnectedRes']
LoginReq = _reflection.GeneratedProtocolMessageType('LoginReq', (_message.Message,), {
  'DESCRIPTOR' : _LOGINREQ,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.LoginReq)
  })
_sym_db.RegisterMessage(LoginReq)

LoginRes = _reflection.GeneratedProtocolMessageType('LoginRes', (_message.Message,), {
  'DESCRIPTOR' : _LOGINRES,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.LoginRes)
  })
_sym_db.RegisterMessage(LoginRes)

BroadcastRelogin = _reflection.GeneratedProtocolMessageType('BroadcastRelogin', (_message.Message,), {
  'DESCRIPTOR' : _BROADCASTRELOGIN,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.BroadcastRelogin)
  })
_sym_db.RegisterMessage(BroadcastRelogin)

BroadcastTakeLeave = _reflection.GeneratedProtocolMessageType('BroadcastTakeLeave', (_message.Message,), {
  'DESCRIPTOR' : _BROADCASTTAKELEAVE,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.BroadcastTakeLeave)
  })
_sym_db.RegisterMessage(BroadcastTakeLeave)

BroadcastDeviceDisconnected = _reflection.GeneratedProtocolMessageType('BroadcastDeviceDisconnected', (_message.Message,), {
  'DESCRIPTOR' : _BROADCASTDEVICEDISCONNECTED,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.BroadcastDeviceDisconnected)
  })
_sym_db.RegisterMessage(BroadcastDeviceDisconnected)

LogoutReq = _reflection.GeneratedProtocolMessageType('LogoutReq', (_message.Message,), {
  'DESCRIPTOR' : _LOGOUTREQ,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.LogoutReq)
  })
_sym_db.RegisterMessage(LogoutReq)

LogoutRes = _reflection.GeneratedProtocolMessageType('LogoutRes', (_message.Message,), {
  'DESCRIPTOR' : _LOGOUTRES,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.LogoutRes)
  })
_sym_db.RegisterMessage(LogoutRes)

DisconnectReq = _reflection.GeneratedProtocolMessageType('DisconnectReq', (_message.Message,), {
  'DESCRIPTOR' : _DISCONNECTREQ,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.DisconnectReq)
  })
_sym_db.RegisterMessage(DisconnectReq)

DisconnectRes = _reflection.GeneratedProtocolMessageType('DisconnectRes', (_message.Message,), {
  'DESCRIPTOR' : _DISCONNECTRES,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.DisconnectRes)
  })
_sym_db.RegisterMessage(DisconnectRes)

UserConInfoListReq = _reflection.GeneratedProtocolMessageType('UserConInfoListReq', (_message.Message,), {
  'DESCRIPTOR' : _USERCONINFOLISTREQ,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.UserConInfoListReq)
  })
_sym_db.RegisterMessage(UserConInfoListReq)

UserConInfoListRes = _reflection.GeneratedProtocolMessageType('UserConInfoListRes', (_message.Message,), {
  'DESCRIPTOR' : _USERCONINFOLISTRES,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.UserConInfoListRes)
  })
_sym_db.RegisterMessage(UserConInfoListRes)

UserConInfo = _reflection.GeneratedProtocolMessageType('UserConInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERCONINFO,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.UserConInfo)
  })
_sym_db.RegisterMessage(UserConInfo)

UserDeviceDisconnectedReq = _reflection.GeneratedProtocolMessageType('UserDeviceDisconnectedReq', (_message.Message,), {
  'DESCRIPTOR' : _USERDEVICEDISCONNECTEDREQ,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.UserDeviceDisconnectedReq)
  })
_sym_db.RegisterMessage(UserDeviceDisconnectedReq)

UserDeviceDisconnectedRes = _reflection.GeneratedProtocolMessageType('UserDeviceDisconnectedRes', (_message.Message,), {
  'DESCRIPTOR' : _USERDEVICEDISCONNECTEDRES,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.UserDeviceDisconnectedRes)
  })
_sym_db.RegisterMessage(UserDeviceDisconnectedRes)

NotifyDeviceDisconnectedReq = _reflection.GeneratedProtocolMessageType('NotifyDeviceDisconnectedReq', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYDEVICEDISCONNECTEDREQ,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.NotifyDeviceDisconnectedReq)
  })
_sym_db.RegisterMessage(NotifyDeviceDisconnectedReq)

NotifyDeviceDisconnectedRes = _reflection.GeneratedProtocolMessageType('NotifyDeviceDisconnectedRes', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYDEVICEDISCONNECTEDRES,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.NotifyDeviceDisconnectedRes)
  })
_sym_db.RegisterMessage(NotifyDeviceDisconnectedRes)

_USERSTATUSEXTOBJ = DESCRIPTOR.services_by_name['UserStatusExtObj']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\242\002\003PB3'
  _USERSTATUSERR._serialized_start=1082
  _USERSTATUSERR._serialized_end=1302
  _USERSTATUSCMDID._serialized_start=1305
  _USERSTATUSCMDID._serialized_end=1442
  _DISCONNECTREASONTYPE._serialized_start=1445
  _DISCONNECTREASONTYPE._serialized_end=1597
  _LOGINREQ._serialized_start=47
  _LOGINREQ._serialized_end=144
  _LOGINRES._serialized_start=146
  _LOGINRES._serialized_end=176
  _BROADCASTRELOGIN._serialized_start=178
  _BROADCASTRELOGIN._serialized_end=273
  _BROADCASTTAKELEAVE._serialized_start=275
  _BROADCASTTAKELEAVE._serialized_end=328
  _BROADCASTDEVICEDISCONNECTED._serialized_start=330
  _BROADCASTDEVICEDISCONNECTED._serialized_end=457
  _LOGOUTREQ._serialized_start=459
  _LOGOUTREQ._serialized_end=522
  _LOGOUTRES._serialized_start=524
  _LOGOUTRES._serialized_end=535
  _DISCONNECTREQ._serialized_start=537
  _DISCONNECTREQ._serialized_end=584
  _DISCONNECTRES._serialized_start=586
  _DISCONNECTRES._serialized_end=601
  _USERCONINFOLISTREQ._serialized_start=603
  _USERCONINFOLISTREQ._serialized_end=623
  _USERCONINFOLISTRES._serialized_start=625
  _USERCONINFOLISTRES._serialized_end=676
  _USERCONINFO._serialized_start=679
  _USERCONINFO._serialized_end=830
  _USERDEVICEDISCONNECTEDREQ._serialized_start=832
  _USERDEVICEDISCONNECTEDREQ._serialized_end=915
  _USERDEVICEDISCONNECTEDRES._serialized_start=917
  _USERDEVICEDISCONNECTEDRES._serialized_end=944
  _NOTIFYDEVICEDISCONNECTEDREQ._serialized_start=946
  _NOTIFYDEVICEDISCONNECTEDREQ._serialized_end=1048
  _NOTIFYDEVICEDISCONNECTEDRES._serialized_start=1050
  _NOTIFYDEVICEDISCONNECTEDRES._serialized_end=1079
  _USERSTATUSEXTOBJ._serialized_start=1600
  _USERSTATUSEXTOBJ._serialized_end=2054
# @@protoc_insertion_point(module_scope)
