# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rpcinput.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0erpcinput.proto\x12\x02pb\"\x82\x01\n\x08RPCInput\x12\x0b\n\x03obj\x18\x01 \x01(\t\x12\x0c\n\x04\x66unc\x18\x02 \x01(\t\x12\x0b\n\x03req\x18\x03 \x01(\x0c\x12\"\n\x03opt\x18\x04 \x03(\x0b\x32\x15.pb.RPCInput.OptEntry\x1a*\n\x08OptEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9f\x01\n\tRPCOutput\x12\x0b\n\x03ret\x18\x01 \x01(\x05\x12\x0b\n\x03rsp\x18\x02 \x01(\x0c\x12#\n\x03opt\x18\x03 \x03(\x0b\x32\x16.pb.RPCOutput.OptEntry\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\x0b\n\x03obj\x18\x05 \x01(\t\x12\x0c\n\x04\x66unc\x18\x06 \x01(\t\x1a*\n\x08OptEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x08\xa2\x02\x05PROTOb\x06proto3')



_RPCINPUT = DESCRIPTOR.message_types_by_name['RPCInput']
_RPCINPUT_OPTENTRY = _RPCINPUT.nested_types_by_name['OptEntry']
_RPCOUTPUT = DESCRIPTOR.message_types_by_name['RPCOutput']
_RPCOUTPUT_OPTENTRY = _RPCOUTPUT.nested_types_by_name['OptEntry']
RPCInput = _reflection.GeneratedProtocolMessageType('RPCInput', (_message.Message,), {

  'OptEntry' : _reflection.GeneratedProtocolMessageType('OptEntry', (_message.Message,), {
    'DESCRIPTOR' : _RPCINPUT_OPTENTRY,
    '__module__' : 'rpcinput_pb2'
    # @@protoc_insertion_point(class_scope:pb.RPCInput.OptEntry)
    })
  ,
  'DESCRIPTOR' : _RPCINPUT,
  '__module__' : 'rpcinput_pb2'
  # @@protoc_insertion_point(class_scope:pb.RPCInput)
  })
_sym_db.RegisterMessage(RPCInput)
_sym_db.RegisterMessage(RPCInput.OptEntry)

RPCOutput = _reflection.GeneratedProtocolMessageType('RPCOutput', (_message.Message,), {

  'OptEntry' : _reflection.GeneratedProtocolMessageType('OptEntry', (_message.Message,), {
    'DESCRIPTOR' : _RPCOUTPUT_OPTENTRY,
    '__module__' : 'rpcinput_pb2'
    # @@protoc_insertion_point(class_scope:pb.RPCOutput.OptEntry)
    })
  ,
  'DESCRIPTOR' : _RPCOUTPUT,
  '__module__' : 'rpcinput_pb2'
  # @@protoc_insertion_point(class_scope:pb.RPCOutput)
  })
_sym_db.RegisterMessage(RPCOutput)
_sym_db.RegisterMessage(RPCOutput.OptEntry)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\242\002\005PROTO'
  _RPCINPUT_OPTENTRY._options = None
  _RPCINPUT_OPTENTRY._serialized_options = b'8\001'
  _RPCOUTPUT_OPTENTRY._options = None
  _RPCOUTPUT_OPTENTRY._serialized_options = b'8\001'
  _RPCINPUT._serialized_start=23
  _RPCINPUT._serialized_end=153
  _RPCINPUT_OPTENTRY._serialized_start=111
  _RPCINPUT_OPTENTRY._serialized_end=153
  _RPCOUTPUT._serialized_start=156
  _RPCOUTPUT._serialized_end=315
  _RPCOUTPUT_OPTENTRY._serialized_start=111
  _RPCOUTPUT_OPTENTRY._serialized_end=153
# @@protoc_insertion_point(module_scope)
